@@ -601,7 +601,7 @@ def filter_daily(dataframe):
 
     daily_aggregated_df['trunc_date'] = daily_aggregated_df.apply(truncate_date, axis=1)
     daily_aggregated_df = daily_aggregated_df.set_index('trunc_date')
-    daily_aggregated_df = daily_aggregated_df.drop(columns=['date'])
+    daily_aggregated_df = daily_aggregated_df.drop(columns=['date','day'])
     return daily_aggregated_df
 
 
